FlutterTreeviewPlus class

Inheritance

Constructors

FlutterTreeviewPlus({Key? key, required List<TreeNodeData> data, dynamic onTap(TreeNodeData node)?, void onCheck(bool? checked, TreeNodeData node)?, void onLoad(TreeNodeData node)?, void onExpand(TreeNodeData node)?, void onCollapse(TreeNodeData node)?, void onAppend(TreeNodeData node, TreeNodeData parent)?, void onRemove(TreeNodeData node, TreeNodeData parent)?, void onChange(List<TreeNodeData> listTreeNode)?, TreeNodeData append(TreeNodeData parent)?, Future<List<TreeNodeData>> load(TreeNodeData parent)?, bool lazy = false, double offsetLeft = 24.0, int? maxLines, bool showFilter = false, String filterPlaceholder = 'Search', bool showActions = false, bool showCheckBox = false, bool contentTappable = false, Widget icon = const Icon(Icons.expand_more, size: 16.0), bool manageParentState = false})
const

Properties

append TreeNodeData Function(TreeNodeData parent)?
final
contentTappable bool
final
data List<TreeNodeData>
final
filterPlaceholder String
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lazy bool
final
load Future<List<TreeNodeData>> Function(TreeNodeData parent)?
final
manageParentState bool
Desired behavior:
final
maxLines int?
final
offsetLeft double
final
onAppend → void Function(TreeNodeData node, TreeNodeData parent)?
final
onChange → void Function(List<TreeNodeData> listTreeNode)?
final
onCheck → void Function(bool? checked, TreeNodeData node)?
final
onCollapse → void Function(TreeNodeData node)?
final
onExpand → void Function(TreeNodeData node)?
final
onLoad → void Function(TreeNodeData node)?
final
onRemove → void Function(TreeNodeData node, TreeNodeData parent)?
final
onTap → dynamic Function(TreeNodeData node)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showActions bool
final
showCheckBox bool
final
showFilter bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlutterTreeviewPlus>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited