TreeNodeData class

Constructors

TreeNodeData({required String title, required bool expanded, required bool? checked, required List<TreeNodeData> children, required TreeNodeData? parent, dynamic extra, Color? checkBoxCheckColor, MaterialStateProperty<Color>? checkBoxFillColor, ValueGetter<Color>? backgroundColor, List<Widget>? customActions})
TreeNodeData.from(TreeNodeData other)

Properties

backgroundColor ValueGetter<Color>?
final
checkBoxCheckColor Color?
final
checkBoxFillColor MaterialStateProperty<Color>?
final
checked bool?
getter/setter pair
children List<TreeNodeData>
getter/setter pair
customActions List<Widget>?
final
expanded bool
getter/setter pair
extra ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
parent TreeNodeData?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited